# Solver defaults
SOLVER_DEFAULT_TOLERANCE = 1e-10
"""Default numerical tolerance for equation solving convergence."""

SOLVER_DEFAULT_MAX_ITERATIONS = 100
"""Default maximum iterations for iterative solvers."""
